Module operation

Module operation 

Shared operation taxonomy and endpoint metadata.

Structs

Endpoint
Provider endpoint metadata used by routing and protocol modules.
OperationKey
Capability plus wire-format kind.
OperationKeyError

Enums

ContentGenerationKind
Content-generation wire formats.
HttpMethod
HTTP method for an upstream endpoint.
Operation
Provider-neutral operation name.
OperationGroup
Coarse operation family, used to organize protocol support by capability.
OperationKind
Wire-format kind used together with Operation.
Provider
Upstream protocol family.