Shared operation taxonomy and endpoint metadata.
Structs
- Endpoint
- Provider endpoint metadata used by routing and protocol modules.
- Operation
Key - Capability plus wire-format kind.
Enums
- Content
Generation Kind - Content-generation wire formats.
- Http
Method - HTTP method for an upstream endpoint.
- Operation
- Provider-neutral operation name.
- Operation
Group - Coarse operation family, used to organize protocol support by capability.
- Operation
Kind - Wire-format kind used together with
Operation. - Provider
- Upstream protocol family.